==> haskell-parsers-0.12.3-11-armv7h.pkg.tar.xz: usr/share/haskell/haskell-parsers/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: parsers
version: 0.12.3
id: parsers-0.12.3-e051a13a9521cc24fdedfec6256ef8b5
key: parse_JO6CfgWE9SR45jHXewyF6O
license: BSD3
copyright: Copyright (C) 2010-2013 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: experimental
homepage: http://github.com/ekmett/parsers/
synopsis: Parsing combinators
description:
    This library provides convenient combinators for working with and building parsing combinator libraries.
    .
    Given a few simple instances, e.g. for the class '\''Text.Parser.Combinators.Parsing'\'' in "Text.Parser.Combinators.Parsing" you
    get access to a large number of canned definitions. Instances exist for the parsers provided by @parsec@,
    @attoparsec@ and base’s "Text.Read".
category: Text, Parsing
author: Edward A. Kmett
exposed: True
exposed-modules:
    Text.Parser.Char Text.Parser.Combinators Text.Parser.LookAhead
    Text.Parser.Permutation Text.Parser.Expression Text.Parser.Token
    Text.Parser.Token.Style Text.Parser.Token.Highlight
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/parsers-0.12.3
library-dirs: /usr/lib/ghc-7.10.3/site-local/parsers-0.12.3
data-dir: /usr/share/arm-linux-ghc-7.10.3/parsers-0.12.3
hs-libraries: HSparsers-0.12.3-JO6CfgWE9SR45jHXewyF6O
depends:
    attoparsec-0.13.0.2-669cbb29a91e49834657a781d3adc2de
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    base-orphans-0.5.4-e40139ef3f9e9946a3f68f9fef66a420
    charset-0.3.7.1-efbce7d7e6d5ad9047eb0bb349210702
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    parsec-3.1.9-3365ddffd9ca11d2f0b377e002b54baf
    scientific-0.3.4.6-7ee193f22b0f4a7e2e484deeaee5cd03
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
haddock-interfaces: /usr/share/doc/haskell-parsers/html/parsers.haddock
haddock-html: /usr/share/doc/haskell-parsers/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-parsers-0.12.3-12-armv7h.pkg.tar.xz: usr/share/haskell/haskell-parsers/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: parsers
version: 0.12.3
id: parsers-0.12.3-b2fd1876091e767ae50d1584dc543a51
key: parse_HJqJQ34XNRdBdZ3TjVJTUH
license: BSD3
copyright: Copyright (C) 2010-2013 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: experimental
homepage: http://github.com/ekmett/parsers/
synopsis: Parsing combinators
description:
    This library provides convenient combinators for working with and building parsing combinator libraries.
    .
    Given a few simple instances, e.g. for the class '\''Text.Parser.Combinators.Parsing'\'' in "Text.Parser.Combinators.Parsing" you
    get access to a large number of canned definitions. Instances exist for the parsers provided by @parsec@,
    @attoparsec@ and base’s "Text.Read".
category: Text, Parsing
author: Edward A. Kmett
exposed: True
exposed-modules:
    Text.Parser.Char Text.Parser.Combinators Text.Parser.LookAhead
    Text.Parser.Permutation Text.Parser.Expression Text.Parser.Token
    Text.Parser.Token.Style Text.Parser.Token.Highlight
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/parsers-0.12.3
library-dirs: /usr/lib/ghc-7.10.3/site-local/parsers-0.12.3
data-dir: /usr/share/arm-linux-ghc-7.10.3/parsers-0.12.3
hs-libraries: HSparsers-0.12.3-HJqJQ34XNRdBdZ3TjVJTUH
depends:
    attoparsec-0.13.0.2-669cbb29a91e49834657a781d3adc2de
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    base-orphans-0.5.4-e40139ef3f9e9946a3f68f9fef66a420
    charset-0.3.7.1-efbce7d7e6d5ad9047eb0bb349210702
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    parsec-3.1.11-2df9dc070a05b018377712731c5dde62
    scientific-0.3.4.6-7ee193f22b0f4a7e2e484deeaee5cd03
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
haddock-interfaces: /usr/share/doc/haskell-parsers/html/parsers.haddock
haddock-html: /usr/share/doc/haskell-parsers/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
